<img src="ASAP_logo.png" align="middle" />

# Dependencies

- pymatgen v >= 2022.0.17 : Older versions of pymatgen have not been tested
- If you have pymatgen installed all other ASAP dependencies should also be isntalled. However, two dependecies you'll want to verify:
- python v >= 3.8
- sympy 

